@@ -11,6 +11,7 @@ url1 = 'https://drive.google.com/uc?id=129jCE5-dWVOHIVgcw4L_g1NhGAsyCu8-'
 output1 = 'model.h5'
 gdown.download(url1, output1, quiet=False)
 print("\nWeights retrieved")
+
 #model.json
 url2 = 'https://drive.google.com/uc?id=1KAUpIPXI1W5TlZmed1LJwyZNgG1ggStR'
 output2 = 'model.json'
@@ -18,7 +19,11 @@ gdown.download(url2, output2, quiet=False)
 print("\nFile (json) retrieved")
 
 from keras.models import model_from_json
-json_file = open('/content/model.json', 'r')
+try:
+  json_file = open('model.json', 'r')
+except:
+  json_file = open('/content/model.json', 'r')
+
 loaded_model_json = json_file.read()
 json_file.close()
 loaded_jarvis = model_from_json(loaded_model_json)
